@@ -37,6 +37,7 @@
 #include "ToolHandler.h"       // for ToolListener
 #include "filesystem.h"        // for path
 
+class LoadHandler;
 class GeometryToolController;
 class AudioController;
 class FullscreenHandler;
@@ -252,9 +253,8 @@ public:
     void block(const std::string& name);
     void unblock();
 
-    void renameLastAutosaveFile();
     void setLastAutosaveFile(fs::path newAutosaveFile);
-    void deleteLastAutosaveFile(fs::path newAutosaveFile);
+    void deleteLastAutosaveFile();
     void setClipboardHandlerSelection(EditSelection* selection);
 
     void addChangedDocumentListener(DocumentListener* dl);
@@ -365,6 +365,11 @@ private:
     void makeGeometryTool();
     void resetGeometryTool();
 
+    /**
+     * Prompt the user that the PDF background is missing and offer solution options
+     */
+    void promptMissingPdf(LoadHandler& loadHandler, const fs::path& filepath);
+
     /**
      * "Closes" the document, preparing the editor for a new document.
      */
