@@ -150,7 +150,7 @@ static void crashHandler(int sig) {
 
     free(messages);
 
-    fp << "\n\nTry to get a better stracktrace...\n";
+    fp << "\n\nTry to get a better stacktrace...\n";
 
     Stacktrace::printStracktrace(fp);
 
